@@ -1,8 +1,10 @@
 """Reproducible configuration across projects."""
 
+from __future__ import annotations
+
 from project_config.constants import Error, InterruptingError, ResultValue
 from project_config.tree import Tree
-from project_config.types import Results, Rule
+from project_config.types import ActionsContext, Results, Rule
 
 
 __all__ = (
@@ -12,4 +14,5 @@ __all__ = (
     "Error",
     "InterruptingError",
     "ResultValue",
+    "ActionsContext",
 )
