@@ -1,14 +1,18 @@
 """Configuration handler."""
 
+from __future__ import annotations
+
+import importlib
 import os
 import re
 import typing as t
 
 from project_config.cache import Cache
-from project_config.compat import TypeAlias
+from project_config.compat import TypeAlias, tomllib_package_name
 from project_config.config.exceptions import (
     ConfigurationFilesNotFound,
     CustomConfigFileNotFound,
+    ProjectConfigAlreadyInitialized,
     ProjectConfigInvalidConfig,
     ProjectConfigInvalidConfigSchema,
     PyprojectTomlFoundButHasNoConfig,
@@ -25,13 +29,17 @@ CONFIG_CACHE_REGEX = (
 ConfigType: TypeAlias = t.Dict[str, t.Union[str, t.List[str]]]
 
 
-def read_config_from_pyproject_toml() -> t.Optional[t.Any]:
+def read_config_from_pyproject_toml(
+    filepath: str = "pyproject.toml",
+) -> t.Optional[t.Any]:
     """Read the configuration from the `pyproject.toml` file.
 
     Returns:
         object: ``None`` if not found, configuration data otherwise.
     """
-    pyproject_toml = fetch("pyproject.toml")
+    tomllib = importlib.import_module(tomllib_package_name)
+    with open(filepath, "rb") as f:
+        pyproject_toml = tomllib.load(f)
     if "tool" in pyproject_toml and "project-config" in pyproject_toml["tool"]:
         return pyproject_toml["tool"]["project-config"]
     return None
@@ -64,9 +72,10 @@ def read_config(
 
     project_config_toml_exists = os.path.isfile(".project-config.toml")
     if project_config_toml_exists:
-        return ".project-config.toml", dict(
-            fetch(".project-config.toml"),
-        )
+        tomllib = importlib.import_module(tomllib_package_name)
+        with open(".project-config.toml", "rb") as f:
+            project_config_toml = tomllib.load(f)
+        return ".project-config.toml", project_config_toml
 
     if pyproject_toml_exists:
         raise PyprojectTomlFoundButHasNoConfig()
@@ -249,11 +258,8 @@ class Config:
         config["cache"] = _cache_string_to_seconds(config["cache"])
 
         # set the cache expiration time globally
-        Cache.set(
-            Cache.Keys.expiration,
-            config["cache"],
-            expire=None,
-        )
+        Cache.set_expiration_time(config["cache"])
+
         # main configuration in file
         self.dict_: ConfigType = config
 
@@ -265,7 +271,7 @@ class Config:
         color: t.Optional[bool],
         reporter: t.Dict[str, t.Any],
         rootdir: str,
-    ) -> t.Tuple[t.Any, t.Dict[str, t.Any], t.Any]:
+    ) -> t.Tuple[t.Any, t.Dict[str, t.Any], t.Any, bool]:
         """Guess the final configuration merging file with CLI arguments."""
         # colorize output?
         color = self.cli.get("color") if color is True else color
@@ -308,10 +314,13 @@ class Config:
                 f"Root directory '{rootdir}' must be an existing directory",
             )
 
+        only_hints = self.cli.get("only_hints") is True
+
         return (
             color,
             reporter,
             self.rootdir,
+            only_hints,
         )
 
     def __getitem__(self, key: str) -> t.Any:
@@ -319,3 +328,143 @@ class Config:
 
     def __setitem__(self, key: str, value: t.Any) -> None:
         self.dict_.__setitem__(key, value)
+
+
+def initialize_config(config_filepath: str) -> str:
+    """Initialize the configuration.
+
+    Args:
+        config_filepath (str): Path to the file in which the configuration will
+            be stored.
+
+    Returns:
+        str: Path to the configuration.
+    """
+    config_dirpath = os.path.join(
+        os.path.abspath(os.path.dirname(config_filepath)),
+    )
+    os.makedirs(config_dirpath, exist_ok=True)
+
+    if not os.path.isfile(config_filepath):
+        with open(config_filepath, "w") as f:
+            f.write("")
+
+    style_filepath = os.path.join(config_dirpath, "style.json5")
+
+    config_file_basename = os.path.basename(config_filepath)
+
+    def create_default_style_file(
+        config_prefix: str = "@",
+        prefix_jmespaths: str = "",
+    ) -> None:
+        """Create the default style file if it does not exist."""
+        if config_prefix == "@":
+
+            def key_matcher(key: str) -> str:
+                return key
+
+            style_setter = "set(@, 'style', ['style.json5'])"
+            cache_setter = "set(@, 'cache', '5 minutes')"
+        else:
+
+            def key_matcher(key: str) -> str:
+                return f'tool.\\"project-config\\".{key}'
+
+            style_setter = (
+                "set(@, 'tool', set(tool, 'project-config',"
+                ' set(tool.\\"project-config\\",'
+                " 'style', ['style.json5'])))"
+            )
+            cache_setter = (
+                "set(@, 'tool', set(tool, 'project-config',"
+                ' set(tool.\\"project-config\\",'
+                " 'cache', '5 minutes')))"
+            )
+
+        with open(style_filepath, "w") as f:
+            f.write(
+                '''{
+  rules: [
+    {
+      files: ["'''
+                + config_file_basename
+                + """"],
+      JMESPathsMatch: [\n        """
+                + prefix_jmespaths
+                + """["type("""
+                + key_matcher("style")
+                + """)", "array"],
+        ["op(length("""
+                + key_matcher("style")
+                + """), '>', `0`)", true, """
+                + '"'
+                + style_setter
+                + '"'
+                + """],
+        ["type("""
+                + key_matcher("cache")
+                + """)", "string", """
+                + '"'
+                + cache_setter
+                + '"'
+                + """],
+        [
+          "regex_match('(\\\\d+ ((seconds?)|(minutes?)|(hours?)|(days?)|(weeks?)))|(never)$', """  # noqa: E501,
+                + key_matcher("cache")
+                + """)",
+          true,
+          "5 minutes",
+        ],
+      ]
+    }
+  ]
+}
+""",
+            )
+
+    def build_config_string(pyproject_toml: bool = False) -> str:
+        result = ""
+        if pyproject_toml:
+            result += "[tool.project-config]\n"
+        return f'{result}style = ["style.json5"]\ncache = "5 minutes"\n'
+
+    def add_config_string_to_file(string: str) -> None:
+        with open(config_filepath, encoding="utf-8") as f:
+            config_lines = f.read().splitlines()
+        if config_lines:
+            add_separator = config_lines[-1] != ""
+        else:
+            add_separator = False
+
+        with open(config_filepath, "a") as f:
+            if add_separator:
+                f.write("\n")
+            f.write(string)
+
+    if config_file_basename == "pyproject.toml":
+        config = read_config_from_pyproject_toml(config_filepath)
+        if config:
+            raise ProjectConfigAlreadyInitialized(
+                f"{config_filepath}[tool.project-config]",
+            )
+
+        add_config_string_to_file(build_config_string(pyproject_toml=True))
+
+        create_default_style_file(
+            config_prefix='tool.\\"project-config\\"',
+            prefix_jmespaths=(
+                '["type(tool)", "object"],'
+                '\n        ["type(tool.\\"project-config\\")", "object"],'
+                "\n        "
+            ),
+        )
+        return f"{config_filepath}[tool.project-config]"
+
+    if os.path.isfile(config_filepath):
+        with open(config_filepath, encoding="utf-8") as f:
+            if f.read():
+                raise ProjectConfigAlreadyInitialized(config_filepath)
+
+    add_config_string_to_file(build_config_string())
+    create_default_style_file()
+    return config_filepath
