@@ -1,7 +1,10 @@
 """High level logic for checking a project."""
 
+from __future__ import annotations
+
 import argparse
 import os
+import shutil
 import sys
 import typing as t
 from dataclasses import dataclass
@@ -10,8 +13,12 @@ from project_config.config import Config
 from project_config.constants import Error, InterruptingError, ResultValue
 from project_config.plugins import InvalidPluginFunction, Plugins
 from project_config.reporters import get_reporter
-from project_config.tree import Tree, TreeNodeFiles
-from project_config.types import Rule
+from project_config.serializers import (
+    build_empty_file_for_serializer,
+    guess_preferred_serializer,
+)
+from project_config.tree import Tree
+from project_config.types import ActionsContext, Rule
 
 
 class InterruptCheck(Exception):
@@ -40,12 +47,16 @@ class Project:
         rootdir (str): Root directory of the project.
         reporter_ (dict): Reporter to use.
         color (bool): Colorized output in reporters.
+        fix (bool): Fix errors.
     """
 
     config_path: str
     rootdir: str
     reporter_: t.Dict[str, t.Any]
     color: bool
+    _actions_context: t.Optional[ActionsContext] = None
+    fix: bool = False
+    only_hints: bool = False
 
     def _load(
         self,
@@ -61,11 +72,13 @@ class Project:
             self.color,
             self.reporter_,
             self.rootdir,
+            config_only_hints,
         ) = self.config.guess_from_cli_arguments(
             self.color,
             self.reporter_,
             self.rootdir,
         )
+        # TODO: Configure fix from config file
 
         if fetch_styles:
             self.config.load_style()
@@ -78,21 +91,45 @@ class Project:
             self.reporter_["kwargs"],
             self.color,
             self.rootdir,
+            only_hints=self.only_hints or config_only_hints,
         )
 
+        # set rootdir as an internal environment variable to be used by plugins
+        os.environ["PROJECT_CONFIG_ROOTDIR"] = self.rootdir
+
+        self._actions_context = ActionsContext(fix=self.fix)
+
     def _check_files_existence(
         self,
-        files: TreeNodeFiles,
+        files: t.List[t.Tuple[str, t.Any]],
         rule_index: int,
     ) -> None:
         for f, (fpath, fcontent) in enumerate(files):
+            ftype = "directory" if fpath.endswith(("/", os.sep)) else "file"
             if fcontent is None:  # file or directory does not exist
-                ftype = "directory" if fpath.endswith(("/", os.sep)) else "file"
+
+                if self.fix:
+                    if ftype == "directory":
+                        os.makedirs(fpath, exist_ok=True)
+                        self.tree.cache_files([fpath])
+                    else:
+                        _, serializer_name = guess_preferred_serializer(fpath)
+                        new_content = (
+                            ""
+                            if not serializer_name
+                            else build_empty_file_for_serializer(
+                                serializer_name,
+                            )
+                        )
+                        with open(fpath, "w", encoding="utf-8") as fd:
+                            fd.write(new_content)
+                        self.tree.cache_files([fpath])
                 self.reporter.report_error(
                     {
                         "message": f"Expected existing {ftype} does not exists",
                         "file": fpath,
                         "definition": f"rules[{rule_index}].files[{f}]",
+                        "fixed": self.fix,
                     },
                 )
 
@@ -101,6 +138,7 @@ class Project:
         files: t.Union[t.List[str], t.Dict[str, str]],
         rule_index: int,
     ) -> None:
+        fixed_files = []
         if isinstance(files, dict):
             for fpath, reason in files.items():
                 normalized_fpath = os.path.join(self.rootdir, fpath)
@@ -111,6 +149,13 @@ class Project:
                     else os.path.isfile(normalized_fpath)
                 )
                 if exists:
+                    if self.fix:
+                        if ftype == "directory":
+                            shutil.rmtree(normalized_fpath)
+                        else:
+                            os.remove(normalized_fpath)
+                        fixed_files.append(fpath)
+
                     message = f"Expected absent {ftype} exists"
                     if reason:
                         message += f". {reason}"
@@ -123,6 +168,7 @@ class Project:
                             "definition": (
                                 f"rules[{rule_index}].files.not[{fpath}]"
                             ),
+                            "fixed": self.fix,
                         },
                     )
         else:
@@ -135,14 +181,24 @@ class Project:
                     else os.path.isfile(normalized_fpath)
                 )
                 if exists:
+                    if self.fix:
+                        if ftype == "directory":
+                            shutil.rmtree(normalized_fpath)
+                        else:
+                            os.remove(normalized_fpath)
+                        fixed_files.append(fpath)
                     self.reporter.report_error(
                         {
                             "message": f"Expected absent {ftype} exists",
                             "file": fpath,
                             "definition": f"rules[{rule_index}].files.not[{f}]",
+                            "fixed": self.fix,
                         },
                     )
 
+        if fixed_files:
+            self.tree.cache_files(fixed_files)
+
     def _process_conditionals_for_rule(
         self,
         conditionals: t.List[str],
@@ -173,6 +229,7 @@ class Project:
                 rule[conditional],  # type: ignore
                 tree,
                 rule,
+                self._actions_context,
             ):
                 if breakage_type in (InterruptingError, Error):
                     breakage_value["definition"] = (
@@ -183,7 +240,7 @@ class Project:
                 elif breakage_type == ResultValue:
                     if breakage_value is False:
                         raise ConditionalsFalseResult()
-                    else:
+                    else:  # pragma: no cover
                         break
                 else:
                     raise NotImplementedError(
@@ -247,6 +304,7 @@ class Project:
                     rule[verb],
                     self.tree,
                     rule,
+                    self._actions_context,
                 ):
                     if breakage_type == Error:
                         # prepend rule index to definition, so plugins do not
@@ -254,10 +312,15 @@ class Project:
                         breakage_value["definition"] = (
                             f"rules[{r}]" + breakage_value["definition"]
                         )
+
+                        if not self.fix:
+                            breakage_value["fixed"] = False
+
                         # show hint if defined in the rule
                         if hint:
                             breakage_value["hint"] = hint
                         self.reporter.report_error(breakage_value)
+
                     elif breakage_type == InterruptingError:
                         breakage_value["definition"] = (
                             f"rules[{r}]" + breakage_value["definition"]
@@ -287,7 +350,7 @@ class Project:
     def show(self, args: argparse.Namespace) -> None:
         """Show configuration or fetched style for a project.
 
-        It will depend in the ``args.data`` property.
+        It will depend in the ``subargs.data`` property.
         """
         if args.data == "cache":
             from project_config.cache import Cache
@@ -318,3 +381,22 @@ class Project:
 
         if Cache.clean():
             sys.stdout.write("Cache removed successfully!\n")
+
+    def init(self, args: argparse.Namespace) -> None:
+        """Initialize the configuration for a project."""
+        from project_config.config import initialize_config
+
+        cwd = os.getcwd()
+        rootdir = (
+            cwd if getattr(args, "rootdir", None) is None else args.rootdir
+        )
+        config_path = initialize_config(
+            os.path.join(
+                rootdir,
+                getattr(args, "config", None) or ".project-config.toml",
+            ),
+        )
+        sys.stdout.write(
+            "Configuration initialized at"
+            f" {os.path.relpath(config_path, cwd)}\n",
+        )
